class Checklist:
    def __init__(self, tpro):
        self.tpro = tpro

    def get_scores(self, turningpoint_id: str) -> str:
        data = self.tpro.rest.get(f"indicator/mtops/score/{turningpoint_id}")
        return data['enabled']

    def get_list(self):
        data = self.tpro.rest.get("indicator/mtops/list")
        return data
