class Handle:
    def __init__(self, time, price):
        self.time = time
        self.price = price

    def get_time(self):
        return self.time

    def get_price(self):
        return self.price
